OC.L10N.register(
    "forms",
    {
    "Forms" : "Formularis",
    "No" : "Non",
    "Yes" : "Òc",
    "Question" : "Question",
    "Copy" : "Copiar",
    "Shared with you" : "Partejat amb vos",
    "No forms created yet" : "Cap de formulari pas encara creat",
    "Cancel" : "Anullar",
    "Options" : "Opcions",
    "Delete" : "Suprimir",
    "never" : "pas jamai",
    "Set expiration date" : "Especificar una data d'expiracion",
    "Group" : "Grop",
    "Permissions" : "Autorizacions",
    "Share link" : "Partejar lo ligam",
    "Add link" : "Apondre un ligam",
    "Copy to clipboard" : "Copiar dins lo quichapapièrs",
    "View" : "Veire",
    "Edit" : "Modificar",
    "Share" : "Partejar",
    "Description" : "Descripcion",
    "Download" : "Teledescargar",
    "Search" : "Recercar",
    "Sharing" : "Partiment",
    "Settings" : "Paramètres",
    "Abort" : "Anullar",
    "Submit" : "Transmetre",
    "Clear" : "Escafar",
    "File" : "Fichier",
    "Date" : "Data",
    "Pick a date" : "Causir una data",
    "Time" : "Ora",
    "Pick a time" : "Causir una ora",
    "Color" : "Color",
    "Document" : "Document",
    "Presentation" : "Presentacion",
    "Text" : "Tèxt",
    "Phone number" : "Numèro de telefòn",
    "Email address" : "Adreça mail",
    "Loading forms …" : "Cargament del formulari...",
    "Uploading …" : "Mandadís…"
},
"nplurals=2; plural=(n > 1);");
